Crate cubiomes_sys

Crate cubiomes_sys 

Raw ffi bindings to the cubiomes library.

This crate also contains module enums for building enums for conviniance

Re-exports

pub use num_traits;

Modules

enums
This module contains generated rust enums representing different cubiomes enums. It also implements display and fromstr for them.

Structs

BiomeFilter
BiomeID
BiomeNoise
BiomeNoiseBeta
BiomeTempCategory
BiomeTree
Dimension
DoublePerlinNoise
EndIsland
EndNoise
FixSpline
Generator
Generator__bindgen_ty_1__bindgen_ty_1
Generator__bindgen_ty_1__bindgen_ty_2
Generator__bindgen_ty_1__bindgen_ty_3
Layer
LayerId
LayerStack
MCVersion
NetherNoise
OctaveNoise
PerlinNoise
Piece
Pos
Pos3
Range
SeaLevelColumnNoiseBeta
Spline
SplineStack
StrongholdIter
StructureConfig
StructureType
StructureVariant
SurfaceNoise
SurfaceNoiseBeta
Xoroshiro
============================================================================= Xoroshiro 128
_G_fpos64_t
_G_fpos_t
_IO_FILE
_IO_codecvt
_IO_cookie_io_functions_t
_IO_marker
_IO_wide_data
__BindgenBitfieldUnit
__atomic_wide_counter__bindgen_ty_1
__fsid_t
__mbstate_t
__once_flag
__pthread_cond_s
__pthread_internal_list
__pthread_internal_slist
__pthread_mutex_s
__pthread_rwlock_arch_t
__sigset_t
__va_list_tag
_bindgen_ty_1
_bindgen_ty_2
_bindgen_ty_3
In 1.18 the Overworld uses a new noise map system for the biome generation. The random number generation also has updated to a Xiroshiro128 algorithm. The scale is 1:4, and is sampled at each point individually as there is currently not much benefit from generating a volume as a whole.
_bindgen_ty_4
_bindgen_ty_5
_bindgen_ty_6
_bindgen_ty_7
_bindgen_ty_8
_bindgen_ty_9
div_t
drand48_data
fd_set
imaxdiv_t
ldiv_t
lldiv_t
max_align_t
random_data
timespec
timeval

Constants

BASE_FLOOR
BASE_ROOF
BF_APPROX
BF_FORCED_OCEAN
BIG_ENDIAN
BRIDGE_CORRIDOR_ENTRANCE
BRIDGE_CROSSING
BRIDGE_END
BRIDGE_FORTIFIED_CROSSING
BRIDGE_GENTLE_STAIRS
BRIDGE_PIECE
BRIDGE_SPAWNER
BRIDGE_STAIRS
BRIDGE_STEEP_STAIRS
BRIDGE_STRAIGHT
BUFSIZ
BYTE_ORDER
Blacksmith
Butcher
CORRIDOR_CROSSING
CORRIDOR_NETHER_WART
CORRIDOR_STAIRS
CORRIDOR_STRAIGHT
CORRIDOR_TURN_LEFT
CORRIDOR_TURN_RIGHT
CORRIDOR_T_CROSSING
CST_BARELY
CST_CLASSIC
CST_IDEAL
CST_NONE
CST_NORMAL
Church
END_CITY_PIECES_MAX
END_SHIP
EOF
EXIT_FAILURE
EXIT_SUCCESS
FAT_TOWER_BASE
FAT_TOWER_MIDDLE
FAT_TOWER_TOP
FD_SETSIZE
FILENAME_MAX
FOPEN_MAX
FORCE_OCEAN_VARIANTS
FORTRESS_END
FORTRESS_START
FP_ILOGB0
FP_ILOGBNAN
FP_INFINITE
FP_NAN
FP_NORMAL
FP_SUBNORMAL
FP_ZERO
FarmLarge
FarmSmall
HOUSE_NUM
HouseLarge
HouseSmall
INT8_MAX
INT8_MIN
INT16_MAX
INT16_MIN
INT32_MAX
INT32_MIN
INTPTR_MAX
INTPTR_MIN
INT_FAST8_MAX
INT_FAST8_MIN
INT_FAST16_MAX
INT_FAST16_MIN
INT_FAST32_MAX
INT_FAST32_MIN
INT_LEAST8_MAX
INT_LEAST8_MIN
INT_LEAST16_MAX
INT_LEAST16_MIN
INT_LEAST32_MAX
INT_LEAST32_MIN
LARGE_BIOMES
LAYER_INIT_SHA
LITTLE_ENDIAN
L_ctermid
L_tmpnam
Library
MATH_ERREXCEPT
MATH_ERRNO
M_1_PI
M_2_PI
M_2_SQRTPI
M_E
M_LN2
M_LN10
M_LOG2E
M_LOG10E
M_PI
M_PI_2
M_PI_4
M_SQRT2
M_SQRT1_2
NO_BETA_OCEAN
NP_CONTINENTALNESS
NP_DEPTH
NP_EROSION
NP_HUMIDITY
NP_MAX
NP_SHIFT
NP_TEMPERATURE
NP_WEIRDNESS
PDP_ENDIAN
PIECE_COUNT
PRIX8
PRIX16
PRIX32
PRIX64
PRIXFAST8
PRIXFAST16
PRIXFAST32
PRIXFAST64
PRIXLEAST8
PRIXLEAST16
PRIXLEAST32
PRIXLEAST64
PRIXMAX
PRIXPTR
PRId8
PRId16
PRId32
PRId64
PRIdFAST8
PRIdFAST16
PRIdFAST32
PRIdFAST64
PRIdLEAST8
PRIdLEAST16
PRIdLEAST32
PRIdLEAST64
PRIdMAX
PRIdPTR
PRIi8
PRIi16
PRIi32
PRIi64
PRIiFAST8
PRIiFAST16
PRIiFAST32
PRIiFAST64
PRIiLEAST8
PRIiLEAST16
PRIiLEAST32
PRIiLEAST64
PRIiMAX
PRIiPTR
PRIo8
PRIo16
PRIo32
PRIo64
PRIoFAST8
PRIoFAST16
PRIoFAST32
PRIoFAST64
PRIoLEAST8
PRIoLEAST16
PRIoLEAST32
PRIoLEAST64
PRIoMAX
PRIoPTR
PRIu8
PRIu16
PRIu32
PRIu64
PRIuFAST8
PRIuFAST16
PRIuFAST32
PRIuFAST64
PRIuLEAST8
PRIuLEAST16
PRIuLEAST32
PRIuLEAST64
PRIuMAX
PRIuPTR
PRIx8
PRIx16
PRIx32
PRIx64
PRIxFAST8
PRIxFAST16
PRIxFAST32
PRIxFAST64
PRIxLEAST8
PRIxLEAST16
PRIxLEAST32
PRIxLEAST64
PRIxMAX
PRIxPTR
PTRDIFF_MAX
PTRDIFF_MIN
P_tmpdir
RAND_MAX
SAMPLE_NO_BIOME
SAMPLE_NO_DEPTH
SAMPLE_NO_SHIFT
SCNd8
SCNd16
SCNd32
SCNd64
SCNdFAST8
SCNdFAST16
SCNdFAST32
SCNdFAST64
SCNdLEAST8
SCNdLEAST16
SCNdLEAST32
SCNdLEAST64
SCNdMAX
SCNdPTR
SCNi8
SCNi16
SCNi32
SCNi64
SCNiFAST8
SCNiFAST16
SCNiFAST32
SCNiFAST64
SCNiLEAST8
SCNiLEAST16
SCNiLEAST32
SCNiLEAST64
SCNiMAX
SCNiPTR
SCNo8
SCNo16
SCNo32
SCNo64
SCNoFAST8
SCNoFAST16
SCNoFAST32
SCNoFAST64
SCNoLEAST8
SCNoLEAST16
SCNoLEAST32
SCNoLEAST64
SCNoMAX
SCNoPTR
SCNu8
SCNu16
SCNu32
SCNu64
SCNuFAST8
SCNuFAST16
SCNuFAST32
SCNuFAST64
SCNuLEAST8
SCNuLEAST16
SCNuLEAST32
SCNuLEAST64
SCNuMAX
SCNuPTR
SCNx8
SCNx16
SCNx32
SCNx64
SCNxFAST8
SCNxFAST16
SCNxFAST32
SCNxFAST64
SCNxLEAST8
SCNxLEAST16
SCNxLEAST32
SCNxLEAST64
SCNxMAX
SCNxPTR
SECOND_FLOOR_1
SECOND_FLOOR_2
SECOND_ROOF
SEEK_CUR
SEEK_END
SEEK_SET
SIG_ATOMIC_MAX
SIG_ATOMIC_MIN
SIZE_MAX
THIRD_FLOOR_1
THIRD_FLOOR_2
THIRD_ROOF
TMP_MAX
TOWER_BASE
TOWER_FLOOR
TOWER_PIECE
TOWER_TOP
UINT8_MAX
UINT16_MAX
UINT32_MAX
UINTPTR_MAX
UINT_FAST8_MAX
UINT_FAST16_MAX
UINT_FAST32_MAX
UINT_LEAST8_MAX
UINT_LEAST16_MAX
UINT_LEAST32_MAX
WCONTINUED
WEXITED
WINT_MAX
WINT_MIN
WNOHANG
WNOWAIT
WSTOPPED
WUNTRACED
WoodHut
_ALLOCA_H
_ATFILE_SOURCE
_BITS_BYTESWAP_H
_BITS_ENDIANNESS_H
_BITS_ENDIAN_H
_BITS_LIBM_SIMD_DECL_STUBS_H
_BITS_PTHREADTYPES_ARCH_H
_BITS_PTHREADTYPES_COMMON_H
_BITS_STDINT_INTN_H
_BITS_STDINT_LEAST_H
_BITS_STDINT_UINTN_H
_BITS_STDIO_LIM_H
_BITS_TIME64_H
_BITS_TYPESIZES_H
_BITS_TYPES_H
_BITS_UINTN_IDENTITY_H
_BITS_WCHAR_H
_DEFAULT_SOURCE
_ENDIAN_H
_FEATURES_H
_INTTYPES_H
_IOFBF
_IOLBF
_IONBF
_IO_EOF_SEEN
_IO_ERR_SEEN
_IO_USER_LOCK
_MATH_H
_POSIX_C_SOURCE
_POSIX_SOURCE
_STDC_PREDEF_H
_STDINT_H
_STDIO_H
_STDLIB_H
_STRUCT_TIMESPEC
_SYS_CDEFS_H
_SYS_SELECT_H
_SYS_TYPES_H
_THREAD_MUTEX_INTERNAL_H
_THREAD_SHARED_TYPES_H
__BIG_ENDIAN
__BIT_TYPES_DEFINED__
__BYTE_ORDER
__FD_SETSIZE
__FILE_defined
__FLOAT_WORD_ORDER
__FP_LOGB0_IS_MIN
__FP_LOGBNAN_IS_MIN
__GLIBC_MINOR__
__GLIBC_USE_C2X_STRTOL
__GLIBC_USE_DEPRECATED_GETS
__GLIBC_USE_DEPRECATED_SCANF
__GLIBC_USE_IEC_60559_BFP_EXT
__GLIBC_USE_IEC_60559_BFP_EXT_C2X
__GLIBC_USE_IEC_60559_EXT
__GLIBC_USE_IEC_60559_FUNCS_EXT
__GLIBC_USE_IEC_60559_FUNCS_EXT_C2X
__GLIBC_USE_IEC_60559_TYPES_EXT
__GLIBC_USE_ISOC2X
__GLIBC_USE_LIB_EXT2
__GLIBC__
__GNU_LIBRARY__
__HAVE_DISTINCT_FLOAT16
__HAVE_DISTINCT_FLOAT32
__HAVE_DISTINCT_FLOAT64
__HAVE_DISTINCT_FLOAT32X
__HAVE_DISTINCT_FLOAT64X
__HAVE_DISTINCT_FLOAT128
__HAVE_DISTINCT_FLOAT128X
__HAVE_FLOAT16
__HAVE_FLOAT32
__HAVE_FLOAT64
__HAVE_FLOAT32X
__HAVE_FLOAT64X
__HAVE_FLOAT64X_LONG_DOUBLE
__HAVE_FLOAT128
__HAVE_FLOAT128X
__HAVE_FLOATN_NOT_TYPEDEF
__HAVE_GENERIC_SELECTION
__INO_T_MATCHES_INO64_T
__KERNEL_OLD_TIMEVAL_MATCHES_TIMEVAL64
__LDOUBLE_REDIRECTS_TO_FLOAT128_ABI
__LITTLE_ENDIAN
__MATH_DECLARE_LDOUBLE
__MATH_DECLARING_DOUBLE
__MATH_DECLARING_FLOATN
__OFF_T_MATCHES_OFF64_T
__PDP_ENDIAN
__PRI64_PREFIX
__PRIPTR_PREFIX
__PTHREAD_MUTEX_HAVE_PREV
__RLIM_T_MATCHES_RLIM64_T
__SIZEOF_PTHREAD_ATTR_T
__SIZEOF_PTHREAD_BARRIERATTR_T
__SIZEOF_PTHREAD_BARRIER_T
__SIZEOF_PTHREAD_CONDATTR_T
__SIZEOF_PTHREAD_COND_T
__SIZEOF_PTHREAD_MUTEXATTR_T
__SIZEOF_PTHREAD_MUTEX_T
__SIZEOF_PTHREAD_RWLOCKATTR_T
__SIZEOF_PTHREAD_RWLOCK_T
__STATFS_MATCHES_STATFS64
__STDC_FORMAT_MACROS
__STDC_IEC_559_COMPLEX__
__STDC_IEC_559__
__STDC_IEC_60559_BFP__
__STDC_IEC_60559_COMPLEX__
__STDC_ISO_10646__
__SYSCALL_WORDSIZE
__TIMESIZE
__USE_ATFILE
__USE_FORTIFY_LEVEL
__USE_ISOC11
__USE_ISOC95
__USE_ISOC99
__USE_MISC
__USE_POSIX
__USE_POSIX2
__USE_POSIX199309
__USE_POSIX199506
__USE_POSIX_IMPLICITLY
__USE_XOPEN2K
__USE_XOPEN2K8
__WALL
__WCLONE
__WCOREFLAG
__WNOTHREAD
__WORDSIZE
__WORDSIZE_TIME64_COMPAT32
__W_CONTINUED
____FILE_defined
_____fpos64_t_defined
_____fpos_t_defined
____gwchar_t_defined
____mbstate_t_defined
__clock_t_defined
__clockid_t_defined
__cookie_io_functions_t_defined
__glibc_c99_flexarr_available
__have_pthread_attr_t
__ldiv_t_defined
__lldiv_t_defined
__sigset_t_defined
__struct_FILE_defined
__time_t_defined
__timer_t_defined
__timeval_defined
math_errhandling

Statics

low20QuadClassic
low20QuadHutBarely
low20QuadHutNormal
low20QuadIdeal
Quad-Witch-Huts
signgam
stderr
stdin
stdout

Functions

_Exit
__acos
__acosf
__acosh
__acoshf
__acoshl
__acosl
__asin
__asinf
__asinh
__asinhf
__asinhl
__asinl
__asprintf
__atan
__atan2
__atan2f
__atan2l
__atanf
__atanh
__atanhf
__atanhl
__atanl
__cbrt
__cbrtf
__cbrtl
__ceil
__ceilf
__ceill
__copysign
__copysignf
__copysignl
__cos
__cosf
__cosh
__coshf
__coshl
__cosl
__ctype_get_mb_cur_max
__drem
__dremf
__dreml
__erf
__erfc
__erfcf
__erfcl
__erff
__erfl
__exp
__exp2
__exp2f
__exp2l
__expf
__expl
__expm1
__expm1f
__expm1l
__fabs
__fabsf
__fabsl
__fdim
__fdimf
__fdiml
__finite
__finitef
__finitel
__floor
__floorf
__floorl
__fma
__fmaf
__fmal
__fmax
__fmaxf
__fmaxl
__fmin
__fminf
__fminl
__fmod
__fmodf
__fmodl
__fpclassify
__fpclassifyf
__fpclassifyl
__frexp
__frexpf
__frexpl
__gamma
__gammaf
__gammal
__getdelim
__hypot
__hypotf
__hypotl
__ilogb
__ilogbf
__ilogbl
__iseqsig
__iseqsigf
__iseqsigl
__isinf
__isinff
__isinfl
__isnan
__isnanf
__isnanl
__issignaling
__issignalingf
__issignalingl
__j0
__j0f
__j0l
__j1
__j1f
__j1l
__jn
__jnf
__jnl
__ldexp
__ldexpf
__ldexpl
__lgamma
__lgamma_r
__lgammaf
__lgammaf_r
__lgammal
__lgammal_r
__llrint
__llrintf
__llrintl
__llround
__llroundf
__llroundl
__log
__log2
__log1p
__log1pf
__log1pl
__log2f
__log2l
__log10
__log10f
__log10l
__logb
__logbf
__logbl
__logf
__logl
__lrint
__lrintf
__lrintl
__lround
__lroundf
__lroundl
__modf
__modff
__modfl
__nan
__nanf
__nanl
__nearbyint
__nearbyintf
__nearbyintl
__nextafter
__nextafterf
__nextafterl
__nexttoward
__nexttowardf
__nexttowardl
__overflow
__pow
__powf
__powl
__remainder
__remainderf
__remainderl
__remquo
__remquof
__remquol
__rint
__rintf
__rintl
__round
__roundf
__roundl
__scalb
__scalbf
__scalbl
__scalbln
__scalblnf
__scalblnl
__scalbn
__scalbnf
__scalbnl
__signbit
__signbitf
__signbitl
__significand
__significandf
__significandl
__sin
__sinf
__sinh
__sinhf
__sinhl
__sinl
__sqrt
__sqrtf
__sqrtl
__tan
__tanf
__tanh
__tanhf
__tanhl
__tanl
__tgamma
__tgammaf
__tgammal
__trunc
__truncf
__truncl
__uflow
__y0
__y0f
__y0l
__y1
__y1f
__y1l
__yn
__ynf
__ynl
a64l
abort
abs
acos
acosf
acosh
acoshf
acoshl
acosl
aligned_alloc
allocCache
alloca
applySeed
Initializes the generator for a given dimension and seed. dim=0: Overworld dim=-1: Nether dim=+1: End
approxSurfaceBeta
arc4random
arc4random_buf
arc4random_uniform
areSimilar
asin
asinf
asinh
asinhf
asinhl
asinl
asprintf
at_quick_exit
atan
atan2
atan2f
atan2l
atanf
atanh
atanhf
atanhl
atanl
atexit
atof
atoi
atol
atoll
biome2str
get the resource id name for a biome (for versions 1.13+)
biomeExists
biomesToImage
bsearch
calloc
canBiomeGenerate
cbrt
cbrtf
cbrtl
ceil
ceilf
ceill
checkForBiomes
checkForBiomesAtLayer
checkForTemps
clearenv
clearerr
clearerr_unlocked
climateToBiome
Uses the global biome tree definitions (see tables/btreeXX.h) to map a noise point (i.e. climate) to the corresponding overworld biome.
copysign
copysignf
copysignl
cos
cosf
cosh
coshf
coshl
cosl
ctermid
div
doublePerlinInit
Double Perlin
dprintf
drand48
drand48_r
drem
dremf
dreml
ecvt
ecvt_r
erand48
erand48_r
erf
erfc
erfcf
erfcl
erff
erfl
estimateSpawn
exit
exp
exp2
exp2f
exp2l
expf
expl
expm1
expm1f
expm1l
fabs
fabsf
fabsl
fclose
fcvt
fcvt_r
fdim
fdimf
fdiml
fdopen
feof
feof_unlocked
ferror
ferror_unlocked
fflush
fflush_unlocked
fgetc
fgetc_unlocked
fgetpos
fgets
fileno
fileno_unlocked
finite
finitef
finitel
flockfile
floor
floorf
floorl
fma
fmaf
fmal
fmax
fmaxf
fmaxl
fmemopen
fmin
fminf
fminl
fmod
fmodf
fmodl
fopen
fopencookie
fprintf
fputc
fputc_unlocked
fputs
fread
fread_unlocked
free
freopen
frexp
frexpf
frexpl
fscanf
fscanf1
fseek
fseeko
fsetpos
ftell
ftello
ftrylockfile
funlockfile
fwrite
fwrite_unlocked
gamma
gammaf
gammal
gcvt
genArea
genBiomeNoiseBetaScaled
Generates the biomes for Beta 1.7, the surface noise is optional and enables ocean mapping in areas that fall below the sea level.
genBiomeNoiseChunkSection
Currently, in 1.18, we have to generate biomes one chunk at a time to get an accurate mapping of the biomes in the level storage, as there is no longer a unique mapping from noise points to biomes (MC-241546). Note that the results from this are not suitable for chunk population/structure generation. The output is in the form out[x][y][z] for the 64 biome points in the chunk section. The coordinates {cx,cy,cz} are all at scale 1:16 and the ‘dat’ argument should be the previous noise sampling and can be left NULL.
genBiomeNoiseScaled
The scaled biome noise generation applies for the Overworld version 1.18+. The ‘sha’ hash of the seed is only required for voronoi at scale 1:1. A scale of zero is interpreted as the default 1:4 scale.
genBiomes
Generates the biomes for a cuboidal scaled range given by ‘r’. (See description of Range for more detail.)
genEndScaled
The scaled End generation supports scales 1, 4, 16, and 64. The End biomes are usually 2D, but in 1.15+ there is 3D voronoi noise, which is controlled by the ‘sha’ hash of the seed. For scales higher than 1:1, and versions up to 1.14, ‘sha’ is ignored.
genNetherScaled
The scaled Nether generation supports scales 1, 4, 16, 64, and 256. It is similar to mapNether3D(), but applies voronoi zoom if necessary, and fills the output buffer with nether_wastes for versions older than 1.16.
genPotential
getAvailableBiomes
getBiomeAt
Gets the biome for a specified scaled position. Note that the scale should be either 1 or 4, for block or biome coordinates respectively. Returns none (-1) upon failure.
getBiomeCenters
getBiomeDepthAndScale
getBiomeParaExtremes
Gets the min/max parameter values within which a biome change can occur.
getBiomeParaLimits
Gets the min/max possible noise parameter values at which the given biome can generate. The values are in min/max pairs in order of: temperature, humidity, continentalness, erosion, depth, weirdness.
getCategory
getDimension
getEndCityPieces
getEndIslands
getEndSurfaceHeight
getFixedEndGateways
getFortressPieces
getHouseList
getLargestRec
Find the largest rectangle in ids[sx][sz] which consists only of ‘match’. The limit corners are written to p0 and p1. Returned is the rectangle’s area.
getLayerForScale
Returns the default layer that corresponds to the given scale. Supported scales are {0, 1, 4, 16, 64, 256}. A scale of zero indicates the custom entry layer ‘g->entry’. (Overworld, MC <= 1.17)
getLinkedGatewayChunk
getLinkedGatewayPos
getMinCacheSize
Calculates the buffer size (number of ints) required to generate a cuboidal volume of size (sx, sy, sz). If ‘sy’ is zero the buffer is calculated for a 2D plane (which is equivalent to sy=1 here). The function allocCache() can be used to allocate the corresponding int buffer using malloc().
getMinLayerCacheSize
getMineshafts
getMutated
getNetherBiome
getOldBetaBiome
(Alpha 1.2 - Beta 1.7) Temperature and humidity values to biome.
getOptimalAfk
getParaDescent
Runs a gradient descent towards the minimum of the noise parameter times a given factor. The algorithm is restricted to the area (x,z,w,h) and starts at (i0,j0) relative to (x,z). The iteration is terminated when either
getParaRange
Determines the value range of a climate noise parameter over the given area. The sampling has scale 1:4 and sampling shift is not considered, so biomes could potentially leak in at the boarders. An optional function: func(data, x, z, climate_noise(x,z)) is called in each gradient descent iteration. If this function returns non-zero the search is aborted, the results are undefined and a non-zero error is returned.
getPossibleBiomesForLimits
Determines which biomes are able to generate given a set of climate parameter limits. Possible biomes are marked non-zero in the ‘ids’.
getQuadHutCst
getSpawn
getStructureConfig
getStructurePos
getVariant
getVoronoiSHA
getVoronoiSrcRange
getc
getc_unlocked
getchar
getchar_unlocked
getdelim
getenv
getline
getloadavg
getsubopt
getw
hypot
hypotf
hypotl
ilogb
ilogbf
ilogbl
imaxabs
imaxdiv
initBiomeColors
initialize a biome colormap with some defaults
initBiomeNoise
initBiomeTypeColors
initFirstStronghold
initSurfaceNoise
initSurfaceNoiseBeta
initstate
initstate_r
isDeepOcean
isEndChunkEmpty
isMesa
isOceanic
isOverworld
isShallowOcean
isSnowy
isViableEndCityTerrain
isViableFeatureBiome
isViableStructurePos
isViableStructureTerrain
isinf
isinff
isinfl
isnan
isnanf
isnanl
j0
j0f
j0l
j1
j1f
j1l
jn
jnf
jnl
jrand48
jrand48_r
l64a
labs
lcong48
lcong48_r
ldexp
ldexpf
ldexpl
ldiv
lgamma
lgamma_r
lgammaf
lgammaf_r
lgammal
lgammal_r
llabs
lldiv
llrint
llrintf
llrintl
llround
llroundf
llroundl
loadSavedSeeds
locateBiome
log
log2
log1p
log1pf
log1pl
log2f
log2l
log10
log10f
log10l
logb
logbf
logbl
logf
logl
lrand48
lrand48_r
lrint
lrintf
lrintl
lround
lroundf
lroundl
malloc
mapApproxHeight
Map an approximation of the Overworld surface height. The horizontal scaling is 1:4. If non-null, the ids are filled with the biomes of the area. The height (written to y) is in blocks.
mapBamboo
mapBiome
mapBiomeEdge
mapContinent
mapCool
mapDeepOcean
mapEnd
mapEndBiome
mapEndIslandHeight
mapEndSurfaceHeight
mapHeat
mapHills
mapIsland
mapLand
mapLand16
mapLandB18
mapMushroom
mapNether2D
mapNether3D
mapNoise
mapOceanMix
mapOceanTemp
mapRiver
mapRiverMix
mapShore
mapSmooth
mapSnow
mapSnow16
mapSpecial
mapSunflower
mapSwampRiver
mapVoronoi
mapVoronoi114
mapVoronoiPlane
mapZoom
mapZoomFuzzy
mblen
mbstowcs
mbtowc
mc2str
convert between version enum and text
mkdtemp
mkstemp
mkstemps
mktemp
modf
modff
modfl
monteCarloBiomes
mrand48
mrand48_r
nan
nanf
nanl
nearbyint
nearbyintf
nearbyintl
nextStronghold
nextafter
nextafterf
nextafterl
nexttoward
nexttowardf
nexttowardl
nrand48
nrand48_r
octaveInit
Perlin Octaves
octaveInitBeta
on_exit
open_memstream
parseBiomeColors
pclose
perlinInit
Perlin noise
perror
popen
posix_memalign
pow
powf
powl
printf
pselect
putc
putc_unlocked
putchar
putchar_unlocked
putenv
puts
putw
qecvt
qecvt_r
qfcvt
qfcvt_r
qgcvt
qsort
quick_exit
rand
rand_r
random
random_r
realloc
reallocarray
realpath
remainder
remainderf
remainderl
remove
remquo
remquof
remquol
rename
renameat
rewind
rint
rintf
rintl
round
roundf
roundl
rpmatch
sampleBiomeNoise
sampleBiomeNoiseBeta
sampleClimatePara
sampleDoublePerlin
sampleOctave
sampleOctave2D
sampleOctaveAmp
sampleOctaveBeta17Biome
sampleOctaveBeta17Terrain
samplePerlin
sampleSimplex2D
sampleSurfaceNoise
sampleSurfaceNoiseBetween
savePPM
scalb
scalbf
scalbl
scalbln
scalblnf
scalblnl
scalbn
scalbnf
scalbnl
scanForQuads
scanf
scanf1
searchAll48
seed48
seed48_r
select
setBetaBiomeSeed
setBiomeSeed
setClimateParaSeed
Initialize BiomeNoise for only a single climate parameter. If nptype == NP_DEPTH, the value is sampled at y=0. Note that this value changes linearly with the height (i.e. -= y/128). A maximum of nmax octaves is set, initializing only the most contributing octaves up to that point. Use -1 for a full initialization.
setEndSeed
End biome generation is based on simplex noise and varies only at a 1:16 chunk scale which can be generated with mapEndBiome(). The function mapEnd() is a variation which also scales this up on a regular grid to 1:4. The final access at a 1:1 scale uses voronoi.
setLayerSeed
setNetherSeed
Nether biomes are 3D, and generated at scale 1:4. Use voronoiAccess3D() to convert coordinates at 1:1 scale to their 1:4 access. Biome checks for structures are generally done at y=0.
setbuf
setbuffer
setenv
setlinebuf
setstate
setstate_r
setupBiomeFilter
setupGenerator
Sets up a biome generator for a given MC version. The ‘flags’ can be used to control LARGE_BIOMES or to FORCE_OCEAN_VARIANTS to enable ocean variants at scales higher than normal.
setupLayer
setupLayerStack
============================================================================= Layered Biome Generation (old interface up to 1.17)
setvbuf
significand
significandf
significandl
sin
sinf
sinh
sinhf
sinhl
sinl
snprintf
sprintf
sqrt
sqrtf
sqrtl
srand
srand48
srand48_r
srandom
srandom_r
sscanf
sscanf1
str2mc
strtod
strtof
strtoimax
strtol
strtold
strtoll
strtoq
strtoul
strtoull
strtoumax
strtouq
struct2str
get the resource id name for a structure
system
tan
tanf
tanh
tanhf
tanhl
tanl
tempnam
tgamma
tgammaf
tgammal
tmpfile
tmpnam
tmpnam_r
trunc
truncf
truncl
ungetc
unsetenv
valloc
vasprintf
vdprintf
vfprintf
vfscanf
vfscanf1
voronoiAccess3D
vprintf
vscanf
vscanf1
vsnprintf
vsprintf
vsscanf
vsscanf1
wcstoimax
wcstombs
wcstoumax
wctomb
xDoublePerlinInit
xOctaveInit
xPerlinInit
y0
y0f
y0l
y1
y1f
y1l
yn
ynf
ynl

Type Aliases

FILE
_Float32
_Float64
_Float32x
_Float64x
_IO_lock_t
__FILE
__blkcnt64_t
__blkcnt_t
__blksize_t
__builtin_va_list
__caddr_t
__clock_t
__clockid_t
__compar_fn_t
__daddr_t
__dev_t
__fd_mask
__fpos64_t
__fpos_t
__fsblkcnt64_t
__fsblkcnt_t
__fsfilcnt64_t
__fsfilcnt_t
__fsword_t
__gid_t
__gnuc_va_list
__gwchar_t
__id_t
__ino64_t
__ino_t
__int8_t
__int16_t
__int32_t
__int64_t
__int_least8_t
__int_least16_t
__int_least32_t
__int_least64_t
__intmax_t
__intptr_t
__key_t
__loff_t
__mode_t
__nlink_t
__off64_t
__off_t
__pid_t
__pthread_list_t
__pthread_slist_t
__quad_t
__rlim64_t
__rlim_t
__sig_atomic_t
__socklen_t
__ssize_t
__suseconds64_t
__suseconds_t
__syscall_slong_t
__syscall_ulong_t
__thrd_t
__time_t
__timer_t
__tss_t
__u_char
__u_int
__u_long
__u_quad_t
__u_short
__uid_t
__uint8_t
__uint16_t
__uint32_t
__uint64_t
__uint_least8_t
__uint_least16_t
__uint_least32_t
__uint_least64_t
__uintmax_t
__useconds_t
blkcnt_t
blksize_t
caddr_t
clock_t
clockid_t
cookie_close_function_t
cookie_io_functions_t
cookie_read_function_t
cookie_seek_function_t
cookie_write_function_t
daddr_t
dev_t
double_t
f32_
f64_
fd_mask
float_t
fpos_t
fsblkcnt_t
fsfilcnt_t
fsid_t
gid_t
i8_
============================================================================= Compiler and Platform Features
i16_
i32_
i64_
id_t
ino_t
int_fast8_t
int_fast16_t
int_fast32_t
int_fast64_t
int_least8_t
int_least16_t
int_least32_t
int_least64_t
intmax_t
key_t
loff_t
mapfunc_t
mode_t
nlink_t
off_t
pid_t
pthread_key_t
pthread_once_t
pthread_spinlock_t
pthread_t
quad_t
register_t
sigset_t
suseconds_t
time_t
timer_t
u8_
u16_
u32_
u64_
u_char
u_int
u_int8_t
u_int16_t
u_int32_t
u_int64_t
u_long
u_quad_t
u_short
uid_t
uint
uint_fast8_t
uint_fast16_t
uint_fast32_t
uint_fast64_t
uint_least8_t
uint_least16_t
uint_least32_t
uint_least64_t
uintmax_t
ulong
ushort
va_list
wchar_t

Unions

Generator__bindgen_ty_1
__atomic_wide_counter
__mbstate_t__bindgen_ty_1
pthread_attr_t
pthread_barrier_t
pthread_barrierattr_t
pthread_cond_t
pthread_condattr_t
pthread_mutex_t
pthread_mutexattr_t
pthread_rwlock_t
pthread_rwlockattr_t