genBiomes

Function genBiomes 

pub unsafe extern "C" fn genBiomes(
    g: *const Generator,
    cache: *mut c_int,
    r: Range,
) -> c_int
Generates the biomes for a cuboidal scaled range given by ‘r’. (See description of Range for more detail.)

The output is generated inside the cache. Upon success the biome ids can be accessed by indexing as: cache[ yr.sxr.sz + z*r.sx + x ] where (x,y,z) is an relative position inside the range cuboid.

The required length of the cache can be determined with getMinCacheSize().

The return value is zero upon success.