getLayerForScale

Function getLayerForScale 

pub unsafe extern "C" fn getLayerForScale(
    g: *const Generator,
    scale: c_int,
) -> *const Layer
Returns the default layer that corresponds to the given scale. Supported scales are {0, 1, 4, 16, 64, 256}. A scale of zero indicates the custom entry layer ‘g->entry’. (Overworld, MC <= 1.17)