getParaRange

Function getParaRange 

pub unsafe extern "C" fn getParaRange(
    para: *const DoublePerlinNoise,
    pmin: *mut f64,
    pmax: *mut f64,
    x: c_int,
    z: c_int,
    w: c_int,
    h: c_int,
    data: *mut c_void,
    func: Option<unsafe extern "C" fn(arg1: *mut c_void, arg2: c_int, arg3: c_int, arg4: f64) -> c_int>,
) -> c_int
Determines the value range of a climate noise parameter over the given area. The sampling has scale 1:4 and sampling shift is not considered, so biomes could potentially leak in at the boarders. An optional function: func(data, x, z, climate_noise(x,z)) is called in each gradient descent iteration. If this function returns non-zero the search is aborted, the results are undefined and a non-zero error is returned.

The results are written to pmin and pmax (which would be cast to an integer during boime mapping). Nullable, to look for minima and maxima separately.