setNetherSeed

Function setNetherSeed 

pub unsafe extern "C" fn setNetherSeed(
    nn: *mut NetherNoise,
    seed: u64,
)
Nether biomes are 3D, and generated at scale 1:4. Use voronoiAccess3D() to convert coordinates at 1:1 scale to their 1:4 access. Biome checks for structures are generally done at y=0.

The function getNetherBiome() determines the nether biome at a given coordinate at scale 1:4. The parameter ‘ndel’ is an output noise delta for optimization purposes and can be ignored (nullable).

Use mapNether2D() to get a 2D area of nether biomes at y=0, scale 1:4.

The mapNether3D() function attempts to optimize the generation of a volume at scale 1:4. The output is indexed as: out[i_y*(r.sxr.sz) + i_zr.sx + i_x]. If the optimization parameter ‘confidence’ has a value less than 1.0, the generation will generally be faster, but can yield incorrect results in some circumstances.

The output buffer for the map-functions need only be of sufficient size to hold the generated area (i.e. wh or r.sxr.sy*r.sz).