setupGenerator

Function setupGenerator 

pub unsafe extern "C" fn setupGenerator(
    g: *mut Generator,
    mc: c_int,
    flags: u32,
)
Sets up a biome generator for a given MC version. The ‘flags’ can be used to control LARGE_BIOMES or to FORCE_OCEAN_VARIANTS to enable ocean variants at scales higher than normal.