#[repr(transparent)]pub struct _bindgen_ty_3(pub c_uint);Expand description
In 1.18 the Overworld uses a new noise map system for the biome generation. The random number generation also has updated to a Xiroshiro128 algorithm. The scale is 1:4, and is sampled at each point individually as there is currently not much benefit from generating a volume as a whole.
The 1.18 End generation remains similar to 1.17 and does NOT use the biome noise.
Tuple Fields
0: c_uintTrait Implementations
Sourceimpl Clone for _bindgen_ty_3
impl Clone for _bindgen_ty_3
Sourcefn clone(&self) -> _bindgen_ty_3
fn clone(&self) -> _bindgen_ty_3
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for _bindgen_ty_3
impl Debug for _bindgen_ty_3
Sourceimpl Hash for _bindgen_ty_3
impl Hash for _bindgen_ty_3
Sourceimpl PartialEq for _bindgen_ty_3
impl PartialEq for _bindgen_ty_3
impl Copy for _bindgen_ty_3
impl Eq for _bindgen_ty_3
impl StructuralPartialEq for _bindgen_ty_3