pub unsafe extern "C" fn getMinCacheSize(
g: *const Generator,
scale: c_int,
sx: c_int,
sy: c_int,
sz: c_int,
) -> usizeExpand description
Calculates the buffer size (number of ints) required to generate a cuboidal volume of size (sx, sy, sz). If ‘sy’ is zero the buffer is calculated for a 2D plane (which is equivalent to sy=1 here). The function allocCache() can be used to allocate the corresponding int buffer using malloc().