pub unsafe extern "C" fn setClimateParaSeed(
bn: *mut BiomeNoise,
seed: u64,
large: c_int,
nptype: c_int,
nmax: c_int,
)Expand description
Initialize BiomeNoise for only a single climate parameter. If nptype == NP_DEPTH, the value is sampled at y=0. Note that this value changes linearly with the height (i.e. -= y/128). A maximum of nmax octaves is set, initializing only the most contributing octaves up to that point. Use -1 for a full initialization.