pub unsafe extern "C" fn setEndSeed(
en: *mut EndNoise,
mc: c_int,
seed: u64,
)Expand description
End biome generation is based on simplex noise and varies only at a 1:16 chunk scale which can be generated with mapEndBiome(). The function mapEnd() is a variation which also scales this up on a regular grid to 1:4. The final access at a 1:1 scale uses voronoi.